Crate display_buffered
source ·Expand description
Provides convinience functions to write all the elements into a writer with buffering
Functions
- Writes all the items into the writer with buffering sepparating them with the new line
- Writes all the bytes from values into the writer with buffering without any separators. Worth noting that values may also consist of String and &str and any other objects that can be turned into &u8 using as_ref method