Crate display_buffered
source ·Expand description
Provides convinience functions to write all the elements into a writer with buffering
Functions
- Writes all the items into the writer with buffering sepparating them with the new line
- Writes all the strings from values into the writer with buffering without any separators