Crate display_buffered

source ·
Provides convinience function to write all the elements into a write with buffering

Functions

  • Writes all the items into the writer with buffering sepparating them with the new line