Crate display_buffered
source ·Expand description
Provides convinience function to write all the elements into a write with buffering
Functions
- Writes all the items into the writer with buffering sepparating them with the new line
Provides convinience function to write all the elements into a write with buffering